@@ -1,13 +1,13 @@
-from typing import Any
+from typing import Any, List
 
-from colour import Color
+from colour import Color  # type: ignore
 from PyQt5 import QtCore, QtGui
 
 
-class LogModel(QtCore.QAbstractTableModel):  # type: ignore
+class LogModel(QtCore.QAbstractTableModel):
     def __init__(self, *args: Any):
         QtCore.QAbstractTableModel.__init__(self, *args)
-        self._entries = []
+        self._entries: List[Any] = []
 
     def rowCount(self, parent: Any = None, *args: Any, **kwargs: Any) -> int:
         return len(self._entries)
@@ -24,10 +24,11 @@ class LogModel(QtCore.QAbstractTableModel):  # type: ignore
         elif role == QtCore.Qt.TextColorRole and index.column() == 2:
             # text colors for log level
             return {
-                'INFO': QtGui.QColor('lime'),
-                'WARNING': QtGui.QColor('orange'),
-                'ERROR': QtGui.QColor('red'),
-                'DEBUG': QtGui.QColor('blue')
+                "INFO": QtGui.QColor("lime"),
+                "WARNING": QtGui.QColor("orange"),
+                "ERROR": QtGui.QColor("red"),
+                "DEBUG": QtGui.QColor("blue"),
+                "CRITICAL": QtGui.QColor("violet"),
             }[self._entries[index.row()][index.column()]]
 
         elif role == QtCore.Qt.TextColorRole and index.column() == 1:
@@ -39,7 +40,7 @@ class LogModel(QtCore.QAbstractTableModel):  # type: ignore
 
     def headerData(self, section: int, orientation: Any, role: Any = None) -> Any:
         if role == QtCore.Qt.DisplayRole and orientation == QtCore.Qt.Horizontal:
-            return ['Time', 'Source', 'Level', 'File', 'Message'][section]
+            return ["Time", "Source", "Level", "File", "Message"][section]
         return QtCore.QAbstractTableModel.headerData(self, section, orientation, role)
 
     @QtCore.pyqtSlot(list)
@@ -49,7 +50,7 @@ class LogModel(QtCore.QAbstractTableModel):  # type: ignore
         self.endInsertRows()
 
 
-class LogModelProxy(QtCore.QSortFilterProxyModel):  # type: ignore
+class LogModelProxy(QtCore.QSortFilterProxyModel):
     def __init__(self, *args: Any):
         QtCore.QSortFilterProxyModel.__init__(self, *args)
         self.setDynamicSortFilter(True)
@@ -75,4 +76,4 @@ class LogModelProxy(QtCore.QSortFilterProxyModel):  # type: ignore
             self.invalidateFilter()
 
 
-__all__ = ['LogModel', 'LogModelProxy']
+__all__ = ["LogModel", "LogModelProxy"]
